@@ -1,8 +1,8 @@
 from .enums import (AllCollectionsEnum, SpecificCollectionsEnum,)
-from .repository import (MenuDTO, OrderListDTO, RestaurantsDTO,
+from .repository import (MenuDTO, OrderDTO, RestaurantDTO,
                         WaiterListDTO, EmployeeDTO, MenuItemsDTO,
                         ConnectionErrors, ParseError, BadRequestError)
-from .parser_json import (XMLRequest, RKXMLRequest,)
+from .parser_xml import (XMLRequest, RKXMLRequest,)
 
 
 __author__ = 'azatbek.t'
