@@ -4,7 +4,7 @@ import os
 print('__file__={0:<35} | __name__={1:<20} | __package__={2:<20}'.format(__file__,__name__,str(__package__)))
 count = 5
 
-from xmlApiParse.parser_json import RKXMLRequest
+from xmlApiParse.parser_xml import RKXMLRequest
 #  xmlApiParse.parser_json import RKXMLRequest
 from dotenv import load_dotenv
 
