@@ -60,7 +60,7 @@ class XMLRequest(ABC):
         pass
 
     @abstractclassmethod
-    def get_menu_items(self):
+    def get_all_menu_items(self):
         pass
 
     @abstractclassmethod
@@ -87,6 +87,9 @@ class XMLRequest(ABC):
     def get_currencies(self):
         pass
 
+    def get_menu_by_categories(self):
+        pass
+
 
 class RKXMLRequest(XMLRequest):
     media_type = "text/xml"
@@ -365,7 +368,7 @@ class RKXMLRequest(XMLRequest):
             raise ParseError(f"XML parse error - {str(error)}")
         return elements
 
-    def get_menu_items(self, name_filter: str = None) -> List[MenuItemsDTO]:
+    def get_all_menu_items(self) -> List[MenuItemsDTO]:
         """For a complete list of dishes or a specific dish"""
 
         body = '<RK7Query><RK7CMD CMD="GetRefData" RefName = "MENUITEMS"/></RK7Query>'
@@ -375,8 +378,6 @@ class RKXMLRequest(XMLRequest):
             parsed_element = Etree.fromstring(response.content)
             for item in parsed_element.findall("./RK7Reference/Items/Item"):
                 if item.attrib['Status'] == 'rsActive' and item.attrib['ActiveHierarchy'] == 'true':
-                    if item.attrib.get('Name') == name_filter:
-                        return item.attrib
                     menu_items_obj = MenuItemsDTO(
                         ident=item.attrib['Ident'], item_ident=item.attrib['ItemIdent'],
                         source_ident=item.attrib['SourceIdent'], guid=item.attrib['GUIDString'],
@@ -431,7 +432,8 @@ class RKXMLRequest(XMLRequest):
                     ident=attr_of_item_node.get('Ident'),
                     name=attr_of_item_node.get('Name'),
                     active_hierarchy=attr_of_item_node.get('ActiveHierarchy'),
-                    main_parent_ident=attr_of_item_node.get('MainParentIdent')
+                    main_parent_ident=attr_of_item_node.get('MainParentIdent'),
+                    parent = attr_of_item_node.get('Parent')
                 )
                 categories.append(category_obj)
         except Exception as error:
@@ -545,3 +547,58 @@ class RKXMLRequest(XMLRequest):
         except Exception as error:
             raise ParseError(f"XML parse error - {str(error)}")
         return currencies
+
+    @staticmethod
+    def get_categories_query(category_ident: str) -> str:
+        return f'<RK7Command CMD="GetRefData" RefName="CATEGLIST" IgnoreEnums="1" WithChildItems="3" WithMacroProp="1" OnlyActive="1" RefItemIdent="{category_ident}"/>'
+
+    def get_menu_by_categories(self, categories_ident: List[str]) -> List[MenuItemsDTO]:
+        categories_query = ''.join(RKXMLRequest.get_categories_query(
+            category_ident=category_ident) for category_ident in categories_ident)
+        body = f'<RK7Query>{categories_query}</RK7Query>'
+        menu_items_list: List[MenuItemsDTO] = []
+        response = self.send_request(body=body)
+        try:
+            parsed_element = Etree.fromstring(response.content)
+            for category in parsed_element.findall("./CommandResult/RK7Reference/Items/"):
+                for item in category.findall('./RIChildItems/TRK7MenuItem'):
+                    menu_items_obj = MenuItemsDTO(
+                        ident=item.attrib['Ident'], item_ident=item.attrib['ItemIdent'],
+                        source_ident=item.attrib['SourceIdent'], guid=item.attrib['GUIDString'],
+                        assign_childs_on_server=item.attrib['AssignChildsOnServer'],
+                        active_hierarchy=item.attrib['ActiveHierarchy'], code=item.attrib['Code'],
+                        name=item.attrib['Name'], alt_name=item.attrib['AltName'],
+                        main_parent_ident=item.attrib['MainParentIdent'], status=item.attrib['Status'],
+                        sales_terms_start_sale=item.attrib['SalesTerms_StartSale'],
+                        sales_terms_stop_sale=item.attrib['SalesTerms_StopSale'],
+                        future_tax_dish_type=item.attrib['FutureTaxDishType'],  parent=item.attrib['Parent'],
+                        cook_mins=item.attrib['CookMins'], modi_weight=item.attrib['ModiWeight'],
+                        min_rest_qnt=item.attrib['MinRestQnt'], categ_path=item.attrib['CategPath'],
+                        price_mode=item.attrib['PriceMode'], modi_scheme=item.attrib['ModiScheme'],
+                        combo_scheme=item.attrib['ComboScheme'], kurs=item.attrib['Kurs'],
+                        qnt_dec_digits=item.attrib['QntDecDigits'], comment=item.attrib['Comment'],
+                        instruct=item.attrib['Instruct'], flags=item.attrib['Flags'],
+                        tara_weight=item.attrib['TaraWeight'], confirm_qnt=item.attrib['ConfirmQnt'],
+                        bar_codes=item.attrib['BarCodes'], open_price=item.attrib['OpenPrice'],
+                        change_qnt_once=item.attrib['ChangeQntOnce'],
+                        use_rest_control=item.attrib['UseRestControl'],
+                        use_confirm_qnt=item.attrib['UseConfirmQnt'],
+                        bar_codes_full_info=item.attrib['BarcodesFullInfo'],
+                        item_kind=item.attrib['ItemKind'],
+                        tariff_round_rule=item.attrib['TariffRoundRule'],
+                        combo_discount=item.attrib['ComboDiscount'],
+                        money_round_rule=item.attrib['MoneyRoundRule'], round_time=item.attrib['RoundTime'],
+                        guests_dish_rating=item.attrib['GuestsDishRating'], rate_type=item.attrib['RateType'],
+                        right_lvl=item.attrib['RightLvl'],
+                        minimum_tarif_time=item.attrib['MinimumTarifTime'],
+                        maximum_tarif_time=item.attrib['MaximumTarifTime'],
+                        ignored_tarif_time=item.attrib['IgnoredTarifTime'],
+                        min_tarif_amount=item.attrib['MinTarifAmount'],
+                        max_tarif_amount=item.attrib['MaxTarifAmount'],
+                        availability_schedule=item.attrib['AvailabilitySchedule'],
+                        dont_pack=item.attrib['DontPack'], portion_weight=item.attrib['PortionWeight'],
+                        portion_name=item.attrib['PortionName'])
+                    menu_items_list.append(menu_items_obj)
+        except Exception as error:
+            raise ParseError(f"XML parse error - {str(error)}")
+        return menu_items_list
